import sys
from PyQt5 import QtCore, QtGui, QtQuick


class Model(QtCore.QAbstractListModel):
    def __init__(self, parent=None):
        super(Model, self).__init__(parent)
        self.items = [
            {"name": "Item1"},
            {"name": "Item2"},
            {"name": "Item3"},
            {"name": "Item4"},
            {"name": "Item5"},
            {"name": "Item6"},
            {"name": "Item12"},
            {"name": "Item13"},
            {"name": "Item14"},
        ]
        self.roles = {
            QtCore.Qt.UserRole + 1: "name"
        }

    def rowCount(self, parent=QtCore.QModelIndex()):
        return len(self.items)

    def data(self, index, role=QtCore.Qt.DisplayRole):
        try:
            item = self.items[index.row()]
        except IndexError:
            return QtCore.QVariant()

        if role in self.roles:
            return item.get(self.roles[role], QtCore.QVariant())

        return QtCore.QVariant()

    def roleNames(self):
        return self.roles


app = QtGui.QGuiApplication(sys.argv)

view = QtQuick.QQuickView()

model = Model()
proxy = QtCore.QSortFilterProxyModel()
proxy.setSourceModel(model)
proxy.setFilterRole(model.roles.keys()[0])
proxy.setFilterCaseSensitivity(QtCore.Qt.CaseInsensitive)

engine = view.engine()
context = engine.rootContext()
context.setContextProperty("qmodel", proxy)

view.setSource(QtCore.QUrl("tst_SortFilter.qml"))
view.setResizeMode(view.SizeRootObjectToView)
view.show()

app.exec_()



"""Pyblish QML command-line interface"""

import sys
import argparse

from . import app


def cli():
    parser = argparse.ArgumentParser()
    parser.add_argument("--demo", action="store_true")
    parser.add_argument("--aschild", action="store_true",
                        help="Run as child of another process")
    parser.add_argument(
        "--targets",
        nargs="*",
        help="Targets to run plugins against."
    )

    kwargs = parser.parse_args()
    if kwargs.targets is None:
        kwargs.targets = []

    return app.main(**kwargs.__dict__)


sys.exit(cli())



"""PyPI setup script

Script includes primary Python package along with essential
non-Python files, such as QML and .png resources.

Usage:
    >>> python setup.py sdist
    ...

"""

import os
import imp
from setuptools import setup, find_packages

with open("README.txt") as f:
    readme = f.read()

version_file = os.path.abspath("pyblish_qml/version.py")
version_mod = imp.load_source("version", version_file)
version = version_mod.version

# Collect non-python data as package data
qml_dir = os.path.abspath('pyblish_qml/qml')
qml_package_data = list()
for root, dirs, files in os.walk(qml_dir):
    for suffix in ("ttf", "qml", "js", "txt", "png", "py", "otf"):
        relpath = os.path.relpath(root, qml_dir)
        relpath = relpath.replace("\\", "/")
        qml_package_data.append("qml/" + relpath.strip(".") + "/*." + suffix)

# qmldir file has no suffix
qml_package_data.append(os.path.join("qml", "Pyblish", "qmldir"))
qml_package_data.append(os.path.join("qml", "Pyblish", "Graphs", "qmldir"))
qml_package_data.append(os.path.join("qml", "Pyblish", "ListItems", "qmldir"))
qml_package_data.append(os.path.join("qml", "Perspective", "qmldir"))

# icon file is in root dir
qml_package_data.append("icon.ico")
qml_package_data.append("splash.png")

classifiers = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
    "Programming Language :: Python",
    "Programming Language :: Python :: 2",
    "Programming Language :: Python :: 2.6",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.1",
    "Programming Language :: Python :: 3.2",
    "Programming Language :: Python :: 3.3",
    "Programming Language :: Python :: 3.4",
    "Programming Language :: Python :: 3.5",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Topic :: Utilities"
]

setup(
    name="pyblish-qml",
    version=version,
    description="Frontend for Pyblish written in PyQt5/QML",
    long_description=readme,
    author="Abstract Factory and Contributors",
    author_email="marcus@abstractfactory.com",
    url="https://github.com/pyblish/pyblish-qml",
    license="LGPL",
    packages=find_packages(),
    zip_safe=False,
    classifiers=classifiers,
    package_data={
        "pyblish_qml": qml_package_data + [
            "vendor/jsonschema/schemas/*.json"
        ],
        "pyblish_qml.ipc": [
            "schema/*.json",
        ]
    },
    install_requires=[
        "pyblish-base==1.5.3"
    ],
    entry_points={},
)



import os
from pyblish_qml import app

tests_path = os.path.dirname(__file__)
qml_path = os.path.dirname(tests_path)
app_path = os.path.join(qml_path, "temp.qml")


if __name__ == "__main__":
    app.main(source=app_path,
             port=6000,
             preload=False,
             debug=True,
             validate=False)
